# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import drivers_pb2 as drivers__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fresources.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\rdrivers.proto\x1a\ntags.proto\"l\n\x15ResourceCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xdf\x01\n\x16ResourceCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"R\n\x12ResourceGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd9\x01\n\x13ResourceGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"x\n\x15ResourceUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12*\n\x08resource\x18\x03 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xdf\x01\n\x16ResourceUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x15ResourceDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb3\x01\n\x16ResourceDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x13ResourceListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xc4\x01\n\x14ResourceListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12+\n\tresources\x18\x02 \x03(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"Y\n\x14\x45numerateTagsRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xbe\x01\n\x15\x45numerateTagsResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12$\n\x07matches\x18\x02 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"i\n\x1aResourceHealthcheckRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb8\x01\n\x1bResourceHealthcheckResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xad\x06\n\tResources\x12p\n\rEnumerateTags\x12\x18.v1.EnumerateTagsRequest\x1a\x19.v1.EnumerateTagsResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/resources/tags/\x12\x66\n\x06\x43reate\x12\x19.v1.ResourceCreateRequest\x1a\x1a.v1.ResourceCreateResponse\"%\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/resources\x12\x61\n\x03Get\x12\x16.v1.ResourceGetRequest\x1a\x17.v1.ResourceGetResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/resources/{id}\x12j\n\x06Update\x12\x19.v1.ResourceUpdateRequest\x1a\x1a.v1.ResourceUpdateResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/resources/{id}\x12m\n\x06\x44\x65lete\x12\x19.v1.ResourceDeleteRequest\x1a\x1a.v1.ResourceDeleteResponse\",\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/resources/{id}\x12_\n\x04List\x12\x17.v1.ResourceListRequest\x1a\x18.v1.ResourceListResponse\"$\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/resources\x12\x85\x01\n\x0bHealthcheck\x12\x1e.v1.ResourceHealthcheckRequest\x1a\x1f.v1.ResourceHealthcheckResponse\"5\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/resources/{id}/healthcheck\x1a\x1f\xca\xf9\xb3\x07\r\xc2\xf9\xb3\x07\x08Resource\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03rs-Be\n\x19\x63om.strongdm.api.plumbingB\x11ResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_RESOURCECREATEREQUEST = DESCRIPTOR.message_types_by_name['ResourceCreateRequest']
_RESOURCECREATERESPONSE = DESCRIPTOR.message_types_by_name['ResourceCreateResponse']
_RESOURCEGETREQUEST = DESCRIPTOR.message_types_by_name['ResourceGetRequest']
_RESOURCEGETRESPONSE = DESCRIPTOR.message_types_by_name['ResourceGetResponse']
_RESOURCEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['ResourceUpdateRequest']
_RESOURCEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['ResourceUpdateResponse']
_RESOURCEDELETEREQUEST = DESCRIPTOR.message_types_by_name['ResourceDeleteRequest']
_RESOURCEDELETERESPONSE = DESCRIPTOR.message_types_by_name['ResourceDeleteResponse']
_RESOURCELISTREQUEST = DESCRIPTOR.message_types_by_name['ResourceListRequest']
_RESOURCELISTRESPONSE = DESCRIPTOR.message_types_by_name['ResourceListResponse']
_ENUMERATETAGSREQUEST = DESCRIPTOR.message_types_by_name['EnumerateTagsRequest']
_ENUMERATETAGSRESPONSE = DESCRIPTOR.message_types_by_name['EnumerateTagsResponse']
_RESOURCEHEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['ResourceHealthcheckRequest']
_RESOURCEHEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['ResourceHealthcheckResponse']
ResourceCreateRequest = _reflection.GeneratedProtocolMessageType('ResourceCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECREATEREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceCreateRequest)
  })
_sym_db.RegisterMessage(ResourceCreateRequest)

ResourceCreateResponse = _reflection.GeneratedProtocolMessageType('ResourceCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECREATERESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceCreateResponse)
  })
_sym_db.RegisterMessage(ResourceCreateResponse)

ResourceGetRequest = _reflection.GeneratedProtocolMessageType('ResourceGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGETREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceGetRequest)
  })
_sym_db.RegisterMessage(ResourceGetRequest)

ResourceGetResponse = _reflection.GeneratedProtocolMessageType('ResourceGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGETRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceGetResponse)
  })
_sym_db.RegisterMessage(ResourceGetResponse)

ResourceUpdateRequest = _reflection.GeneratedProtocolMessageType('ResourceUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEUPDATEREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceUpdateRequest)
  })
_sym_db.RegisterMessage(ResourceUpdateRequest)

ResourceUpdateResponse = _reflection.GeneratedProtocolMessageType('ResourceUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEUPDATERESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceUpdateResponse)
  })
_sym_db.RegisterMessage(ResourceUpdateResponse)

ResourceDeleteRequest = _reflection.GeneratedProtocolMessageType('ResourceDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEDELETEREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceDeleteRequest)
  })
_sym_db.RegisterMessage(ResourceDeleteRequest)

ResourceDeleteResponse = _reflection.GeneratedProtocolMessageType('ResourceDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEDELETERESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceDeleteResponse)
  })
_sym_db.RegisterMessage(ResourceDeleteResponse)

ResourceListRequest = _reflection.GeneratedProtocolMessageType('ResourceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCELISTREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceListRequest)
  })
_sym_db.RegisterMessage(ResourceListRequest)

ResourceListResponse = _reflection.GeneratedProtocolMessageType('ResourceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCELISTRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceListResponse)
  })
_sym_db.RegisterMessage(ResourceListResponse)

EnumerateTagsRequest = _reflection.GeneratedProtocolMessageType('EnumerateTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENUMERATETAGSREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.EnumerateTagsRequest)
  })
_sym_db.RegisterMessage(EnumerateTagsRequest)

EnumerateTagsResponse = _reflection.GeneratedProtocolMessageType('EnumerateTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENUMERATETAGSRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.EnumerateTagsResponse)
  })
_sym_db.RegisterMessage(EnumerateTagsResponse)

ResourceHealthcheckRequest = _reflection.GeneratedProtocolMessageType('ResourceHealthcheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHEALTHCHECKREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceHealthcheckRequest)
  })
_sym_db.RegisterMessage(ResourceHealthcheckRequest)

ResourceHealthcheckResponse = _reflection.GeneratedProtocolMessageType('ResourceHealthcheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHEALTHCHECKRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceHealthcheckResponse)
  })
_sym_db.RegisterMessage(ResourceHealthcheckResponse)

_RESOURCES = DESCRIPTOR.services_by_name['Resources']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\021ResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _RESOURCECREATEREQUEST.fields_by_name['resource']._options = None
  _RESOURCECREATEREQUEST.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCECREATERESPONSE.fields_by_name['meta']._options = None
  _RESOURCECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCECREATERESPONSE.fields_by_name['resource']._options = None
  _RESOURCECREATERESPONSE.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCECREATERESPONSE._options = None
  _RESOURCECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEGETREQUEST.fields_by_name['id']._options = None
  _RESOURCEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEGETRESPONSE.fields_by_name['meta']._options = None
  _RESOURCEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEGETRESPONSE.fields_by_name['resource']._options = None
  _RESOURCEGETRESPONSE.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEGETRESPONSE._options = None
  _RESOURCEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEUPDATEREQUEST.fields_by_name['resource']._options = None
  _RESOURCEUPDATEREQUEST.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEUPDATERESPONSE.fields_by_name['meta']._options = None
  _RESOURCEUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEUPDATERESPONSE.fields_by_name['resource']._options = None
  _RESOURCEUPDATERESPONSE.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEUPDATERESPONSE._options = None
  _RESOURCEUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEDELETEREQUEST.fields_by_name['id']._options = None
  _RESOURCEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEDELETERESPONSE.fields_by_name['meta']._options = None
  _RESOURCEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEDELETERESPONSE._options = None
  _RESOURCEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCELISTREQUEST.fields_by_name['filter']._options = None
  _RESOURCELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCELISTRESPONSE.fields_by_name['resources']._options = None
  _RESOURCELISTRESPONSE.fields_by_name['resources']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _RESOURCELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ENUMERATETAGSREQUEST.fields_by_name['filter']._options = None
  _ENUMERATETAGSREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ENUMERATETAGSRESPONSE.fields_by_name['matches']._options = None
  _ENUMERATETAGSRESPONSE.fields_by_name['matches']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ENUMERATETAGSRESPONSE.fields_by_name['rate_limit']._options = None
  _ENUMERATETAGSRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEHEALTHCHECKREQUEST.fields_by_name['id']._options = None
  _RESOURCEHEALTHCHECKREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHEALTHCHECKREQUEST._options = None
  _RESOURCEHEALTHCHECKREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['meta']._options = None
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEHEALTHCHECKRESPONSE._options = None
  _RESOURCEHEALTHCHECKRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCES._options = None
  _RESOURCES._serialized_options = b'\312\371\263\007\r\302\371\263\007\010Resource\312\371\263\007\010\322\371\263\007\003rs-'
  _RESOURCES.methods_by_name['EnumerateTags']._options = None
  _RESOURCES.methods_by_name['EnumerateTags']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\030\252\363\263\007\023/v1/resources/tags/'
  _RESOURCES.methods_by_name['Create']._options = None
  _RESOURCES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\022\252\363\263\007\r/v1/resources'
  _RESOURCES.methods_by_name['Get']._options = None
  _RESOURCES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/resources/{id}'
  _RESOURCES.methods_by_name['Update']._options = None
  _RESOURCES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\027\252\363\263\007\022/v1/resources/{id}'
  _RESOURCES.methods_by_name['Delete']._options = None
  _RESOURCES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\027\252\363\263\007\022/v1/resources/{id}'
  _RESOURCES.methods_by_name['List']._options = None
  _RESOURCES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\022\252\363\263\007\r/v1/resources'
  _RESOURCES.methods_by_name['Healthcheck']._options = None
  _RESOURCES.methods_by_name['Healthcheck']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007#\252\363\263\007\036/v1/resources/{id}/healthcheck'
  _RESOURCECREATEREQUEST._serialized_start=77
  _RESOURCECREATEREQUEST._serialized_end=185
  _RESOURCECREATERESPONSE._serialized_start=188
  _RESOURCECREATERESPONSE._serialized_end=411
  _RESOURCEGETREQUEST._serialized_start=413
  _RESOURCEGETREQUEST._serialized_end=495
  _RESOURCEGETRESPONSE._serialized_start=498
  _RESOURCEGETRESPONSE._serialized_end=715
  _RESOURCEUPDATEREQUEST._serialized_start=717
  _RESOURCEUPDATEREQUEST._serialized_end=837
  _RESOURCEUPDATERESPONSE._serialized_start=840
  _RESOURCEUPDATERESPONSE._serialized_end=1063
  _RESOURCEDELETEREQUEST._serialized_start=1065
  _RESOURCEDELETEREQUEST._serialized_end=1153
  _RESOURCEDELETERESPONSE._serialized_start=1156
  _RESOURCEDELETERESPONSE._serialized_end=1335
  _RESOURCELISTREQUEST._serialized_start=1337
  _RESOURCELISTREQUEST._serialized_end=1425
  _RESOURCELISTRESPONSE._serialized_start=1428
  _RESOURCELISTRESPONSE._serialized_end=1624
  _ENUMERATETAGSREQUEST._serialized_start=1626
  _ENUMERATETAGSREQUEST._serialized_end=1715
  _ENUMERATETAGSRESPONSE._serialized_start=1718
  _ENUMERATETAGSRESPONSE._serialized_end=1908
  _RESOURCEHEALTHCHECKREQUEST._serialized_start=1910
  _RESOURCEHEALTHCHECKREQUEST._serialized_end=2015
  _RESOURCEHEALTHCHECKRESPONSE._serialized_start=2018
  _RESOURCEHEALTHCHECKRESPONSE._serialized_end=2202
  _RESOURCES._serialized_start=2205
  _RESOURCES._serialized_end=3018
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

from setuptools import setup
setup(
    name='strongdm',
    packages=['strongdm'],
    version='16.3.0',
    license='apache-2.0',
    description='strongDM SDK for the Python programming language.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='strongDM Team',
    author_email='sdk-feedback@strongdm.com',
    url='https://github.com/strongdm/strongdm-sdk-python',
    download_url=
    'https://github.com/strongdm/strongdm-sdk-python/archive/v16.3.0.tar.gz',
    keywords=[
        'strongDM', 'sdm', 'api', 'automation', 'security', 'audit',
        'database', 'server', 'ssh', 'rdp'
    ],
    install_requires=[
        'grpcio >= 1.42.0', 'googleapis-common-protos>1.56.2,<2',
        'cryptography >= 46.0.0'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',
        'Topic :: Security',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
    ],
)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: accounts_groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61\x63\x63ounts_groups.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x93\x01\n\x19\x41\x63\x63ountGroupCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\raccount_group\x18\x02 \x01(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xcc\x01\n\x1a\x41\x63\x63ountGroupCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x33\n\raccount_group\x18\x02 \x01(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"p\n\x16\x41\x63\x63ountGroupGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xd2\x01\n\x17\x41\x63\x63ountGroupGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\raccount_group\x18\x02 \x01(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"v\n\x19\x41\x63\x63ountGroupDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xa3\x01\n\x1a\x41\x63\x63ountGroupDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"v\n\x17\x41\x63\x63ountGroupListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc9\x01\n\x18\x41\x63\x63ountGroupListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0e\x61\x63\x63ount_groups\x18\x02 \x03(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xe6\x01\n\x0c\x41\x63\x63ountGroup\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x08group_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:v\xfa\xf8\xb3\x07q\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07Y\xa2\xf3\xb3\x07&tf_examples/account_group_resource.txt\xaa\xf3\xb3\x07)tf_examples/account_group_data_source.txt\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li2\xa1\x04\n\x0e\x41\x63\x63ountsGroups\x12s\n\x06\x43reate\x12\x1d.v1.AccountGroupCreateRequest\x1a\x1e.v1.AccountGroupCreateResponse\"*\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/accountsgroups\x12n\n\x03Get\x12\x1a.v1.AccountGroupGetRequest\x1a\x1b.v1.AccountGroupGetResponse\".\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/accountsgroups/{id}\x12z\n\x06\x44\x65lete\x12\x1d.v1.AccountGroupDeleteRequest\x1a\x1e.v1.AccountGroupDeleteResponse\"1\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/accountsgroups/{id}\x12l\n\x04List\x12\x1b.v1.AccountGroupListRequest\x1a\x1c.v1.AccountGroupListResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/accountsgroups\x1a@\xca\xf9\xb3\x07\x31\xc2\xf9\xb3\x07\x0c\x41\x63\x63ountGroup\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x03\x63li\xd2\xf9\xb3\x07\raccountgroup-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x82\x01\n\x19\x63om.strongdm.api.plumbingB\x16\x41\x63\x63ountsGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x08\xa2\x8c\xb4\x07\x03\x63lib\x06proto3')



_ACCOUNTGROUPCREATEREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupCreateRequest']
_ACCOUNTGROUPCREATERESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupCreateResponse']
_ACCOUNTGROUPGETREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupGetRequest']
_ACCOUNTGROUPGETRESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupGetResponse']
_ACCOUNTGROUPDELETEREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupDeleteRequest']
_ACCOUNTGROUPDELETERESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupDeleteResponse']
_ACCOUNTGROUPLISTREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupListRequest']
_ACCOUNTGROUPLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupListResponse']
_ACCOUNTGROUP = DESCRIPTOR.message_types_by_name['AccountGroup']
AccountGroupCreateRequest = _reflection.GeneratedProtocolMessageType('AccountGroupCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPCREATEREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupCreateRequest)
  })
_sym_db.RegisterMessage(AccountGroupCreateRequest)

AccountGroupCreateResponse = _reflection.GeneratedProtocolMessageType('AccountGroupCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPCREATERESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupCreateResponse)
  })
_sym_db.RegisterMessage(AccountGroupCreateResponse)

AccountGroupGetRequest = _reflection.GeneratedProtocolMessageType('AccountGroupGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPGETREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupGetRequest)
  })
_sym_db.RegisterMessage(AccountGroupGetRequest)

AccountGroupGetResponse = _reflection.GeneratedProtocolMessageType('AccountGroupGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPGETRESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupGetResponse)
  })
_sym_db.RegisterMessage(AccountGroupGetResponse)

AccountGroupDeleteRequest = _reflection.GeneratedProtocolMessageType('AccountGroupDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPDELETEREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupDeleteRequest)
  })
_sym_db.RegisterMessage(AccountGroupDeleteRequest)

AccountGroupDeleteResponse = _reflection.GeneratedProtocolMessageType('AccountGroupDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPDELETERESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupDeleteResponse)
  })
_sym_db.RegisterMessage(AccountGroupDeleteResponse)

AccountGroupListRequest = _reflection.GeneratedProtocolMessageType('AccountGroupListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPLISTREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupListRequest)
  })
_sym_db.RegisterMessage(AccountGroupListRequest)

AccountGroupListResponse = _reflection.GeneratedProtocolMessageType('AccountGroupListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPLISTRESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupListResponse)
  })
_sym_db.RegisterMessage(AccountGroupListResponse)

AccountGroup = _reflection.GeneratedProtocolMessageType('AccountGroup', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUP,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroup)
  })
_sym_db.RegisterMessage(AccountGroup)

_ACCOUNTSGROUPS = DESCRIPTOR.services_by_name['AccountsGroups']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\026AccountsGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\010\242\214\264\007\003cli'
  _ACCOUNTGROUPCREATEREQUEST.fields_by_name['account_group']._options = None
  _ACCOUNTGROUPCREATEREQUEST.fields_by_name['account_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPCREATEREQUEST._options = None
  _ACCOUNTGROUPCREATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['account_group']._options = None
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['account_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPCREATERESPONSE._options = None
  _ACCOUNTGROUPCREATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPGETREQUEST.fields_by_name['id']._options = None
  _ACCOUNTGROUPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETREQUEST._options = None
  _ACCOUNTGROUPGETREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['account_group']._options = None
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['account_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETRESPONSE._options = None
  _ACCOUNTGROUPGETRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPDELETEREQUEST.fields_by_name['id']._options = None
  _ACCOUNTGROUPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPDELETEREQUEST._options = None
  _ACCOUNTGROUPDELETEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPDELETERESPONSE._options = None
  _ACCOUNTGROUPDELETERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPLISTREQUEST.fields_by_name['filter']._options = None
  _ACCOUNTGROUPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPLISTREQUEST._options = None
  _ACCOUNTGROUPLISTREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['account_groups']._options = None
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['account_groups']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPLISTRESPONSE._options = None
  _ACCOUNTGROUPLISTRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUP.fields_by_name['id']._options = None
  _ACCOUNTGROUP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUP.fields_by_name['account_id']._options = None
  _ACCOUNTGROUP.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTGROUP.fields_by_name['group_id']._options = None
  _ACCOUNTGROUP.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTGROUP._options = None
  _ACCOUNTGROUP._serialized_options = b'\372\370\263\007q\250\363\263\007\001\302\363\263\007Y\242\363\263\007&tf_examples/account_group_resource.txt\252\363\263\007)tf_examples/account_group_data_source.txt\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTSGROUPS._options = None
  _ACCOUNTSGROUPS._serialized_options = b'\312\371\263\0071\302\371\263\007\014AccountGroup\312\371\263\007\001*\312\371\263\007\003cli\322\371\263\007\raccountgroup-\312\371\263\007\005\350\371\263\007\001'
  _ACCOUNTSGROUPS.methods_by_name['Create']._options = None
  _ACCOUNTSGROUPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\027\252\363\263\007\022/v1/accountsgroups'
  _ACCOUNTSGROUPS.methods_by_name['Get']._options = None
  _ACCOUNTSGROUPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\034\252\363\263\007\027/v1/accountsgroups/{id}'
  _ACCOUNTSGROUPS.methods_by_name['Delete']._options = None
  _ACCOUNTSGROUPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\034\252\363\263\007\027/v1/accountsgroups/{id}'
  _ACCOUNTSGROUPS.methods_by_name['List']._options = None
  _ACCOUNTSGROUPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/accountsgroups'
  _ACCOUNTGROUPCREATEREQUEST._serialized_start=57
  _ACCOUNTGROUPCREATEREQUEST._serialized_end=204
  _ACCOUNTGROUPCREATERESPONSE._serialized_start=207
  _ACCOUNTGROUPCREATERESPONSE._serialized_end=411
  _ACCOUNTGROUPGETREQUEST._serialized_start=413
  _ACCOUNTGROUPGETREQUEST._serialized_end=525
  _ACCOUNTGROUPGETRESPONSE._serialized_start=528
  _ACCOUNTGROUPGETRESPONSE._serialized_end=738
  _ACCOUNTGROUPDELETEREQUEST._serialized_start=740
  _ACCOUNTGROUPDELETEREQUEST._serialized_end=858
  _ACCOUNTGROUPDELETERESPONSE._serialized_start=861
  _ACCOUNTGROUPDELETERESPONSE._serialized_end=1024
  _ACCOUNTGROUPLISTREQUEST._serialized_start=1026
  _ACCOUNTGROUPLISTREQUEST._serialized_end=1144
  _ACCOUNTGROUPLISTRESPONSE._serialized_start=1147
  _ACCOUNTGROUPLISTRESPONSE._serialized_end=1348
  _ACCOUNTGROUP._serialized_start=1351
  _ACCOUNTGROUP._serialized_end=1581
  _ACCOUNTSGROUPS._serialized_start=1584
  _ACCOUNTSGROUPS._serialized_end=2129
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workflow_approvers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18workflow_approvers.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x92\x01\n\x1eWorkflowApproversCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12;\n\x11workflow_approver\x18\x02 \x01(\x0b\x32\x14.v1.WorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xed\x01\n\x1fWorkflowApproversCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12;\n\x11workflow_approver\x18\x02 \x01(\x0b\x32\x14.v1.WorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"Z\n\x1aWorkflowApproverGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf2\x01\n\x1bWorkflowApproverGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12;\n\x11workflow_approver\x18\x02 \x01(\x0b\x32\x14.v1.WorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"m\n\x1eWorkflowApproversDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb0\x01\n\x1fWorkflowApproversDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"s\n\x1cWorkflowApproversListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xf0\x01\n\x1dWorkflowApproversListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12<\n\x12workflow_approvers\x18\x02 \x03(\x0b\x32\x14.v1.WorkflowApproverB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xa1\x01\n\x10WorkflowApprover\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bworkflow_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1e\n\naccount_id\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07role_id\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x12\x18\x01\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*2\xc7\x04\n\x11WorkflowApprovers\x12\x81\x01\n\x06\x43reate\x12\".v1.WorkflowApproversCreateRequest\x1a#.v1.WorkflowApproversCreateResponse\".\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/workflow-approvers\x12y\n\x03Get\x12\x1e.v1.WorkflowApproverGetRequest\x1a\x1f.v1.WorkflowApproverGetResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/workflow-approver/{id}\x12\x83\x01\n\x06\x44\x65lete\x12\".v1.WorkflowApproversDeleteRequest\x1a#.v1.WorkflowApproversDeleteResponse\"0\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/workflow-approvers\x12z\n\x04List\x12 .v1.WorkflowApproversListRequest\x1a!.v1.WorkflowApproversListResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/workflow-approvers\x1a\x31\xca\xf9\xb3\x07\x15\xc2\xf9\xb3\x07\x10WorkflowApprover\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03nt-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42m\n\x19\x63om.strongdm.api.plumbingB\x19WorkflowApproversPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_WORKFLOWAPPROVERSCREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowApproversCreateRequest']
_WORKFLOWAPPROVERSCREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowApproversCreateResponse']
_WORKFLOWAPPROVERGETREQUEST = DESCRIPTOR.message_types_by_name['WorkflowApproverGetRequest']
_WORKFLOWAPPROVERGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowApproverGetResponse']
_WORKFLOWAPPROVERSDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowApproversDeleteRequest']
_WORKFLOWAPPROVERSDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowApproversDeleteResponse']
_WORKFLOWAPPROVERSLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkflowApproversListRequest']
_WORKFLOWAPPROVERSLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowApproversListResponse']
_WORKFLOWAPPROVER = DESCRIPTOR.message_types_by_name['WorkflowApprover']
WorkflowApproversCreateRequest = _reflection.GeneratedProtocolMessageType('WorkflowApproversCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERSCREATEREQUEST,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproversCreateRequest)
  })
_sym_db.RegisterMessage(WorkflowApproversCreateRequest)

WorkflowApproversCreateResponse = _reflection.GeneratedProtocolMessageType('WorkflowApproversCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERSCREATERESPONSE,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproversCreateResponse)
  })
_sym_db.RegisterMessage(WorkflowApproversCreateResponse)

WorkflowApproverGetRequest = _reflection.GeneratedProtocolMessageType('WorkflowApproverGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERGETREQUEST,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproverGetRequest)
  })
_sym_db.RegisterMessage(WorkflowApproverGetRequest)

WorkflowApproverGetResponse = _reflection.GeneratedProtocolMessageType('WorkflowApproverGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERGETRESPONSE,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproverGetResponse)
  })
_sym_db.RegisterMessage(WorkflowApproverGetResponse)

WorkflowApproversDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkflowApproversDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERSDELETEREQUEST,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproversDeleteRequest)
  })
_sym_db.RegisterMessage(WorkflowApproversDeleteRequest)

WorkflowApproversDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkflowApproversDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERSDELETERESPONSE,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproversDeleteResponse)
  })
_sym_db.RegisterMessage(WorkflowApproversDeleteResponse)

WorkflowApproversListRequest = _reflection.GeneratedProtocolMessageType('WorkflowApproversListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERSLISTREQUEST,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproversListRequest)
  })
_sym_db.RegisterMessage(WorkflowApproversListRequest)

WorkflowApproversListResponse = _reflection.GeneratedProtocolMessageType('WorkflowApproversListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVERSLISTRESPONSE,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApproversListResponse)
  })
_sym_db.RegisterMessage(WorkflowApproversListResponse)

WorkflowApprover = _reflection.GeneratedProtocolMessageType('WorkflowApprover', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWAPPROVER,
  '__module__' : 'workflow_approvers_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowApprover)
  })
_sym_db.RegisterMessage(WorkflowApprover)

_WORKFLOWAPPROVERS = DESCRIPTOR.services_by_name['WorkflowApprovers']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\031WorkflowApproversPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _WORKFLOWAPPROVERSCREATEREQUEST.fields_by_name['workflow_approver']._options = None
  _WORKFLOWAPPROVERSCREATEREQUEST.fields_by_name['workflow_approver']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVERSCREATEREQUEST._options = None
  _WORKFLOWAPPROVERSCREATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWAPPROVERSCREATERESPONSE.fields_by_name['workflow_approver']._options = None
  _WORKFLOWAPPROVERSCREATERESPONSE.fields_by_name['workflow_approver']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVERSCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWAPPROVERSCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWAPPROVERSCREATERESPONSE._options = None
  _WORKFLOWAPPROVERSCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWAPPROVERGETREQUEST.fields_by_name['id']._options = None
  _WORKFLOWAPPROVERGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVERGETRESPONSE.fields_by_name['meta']._options = None
  _WORKFLOWAPPROVERGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVERGETRESPONSE.fields_by_name['workflow_approver']._options = None
  _WORKFLOWAPPROVERGETRESPONSE.fields_by_name['workflow_approver']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVERGETRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWAPPROVERGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWAPPROVERGETRESPONSE._options = None
  _WORKFLOWAPPROVERGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWAPPROVERSDELETEREQUEST.fields_by_name['id']._options = None
  _WORKFLOWAPPROVERSDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVERSDELETEREQUEST._options = None
  _WORKFLOWAPPROVERSDELETEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWAPPROVERSDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWAPPROVERSDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWAPPROVERSDELETERESPONSE._options = None
  _WORKFLOWAPPROVERSDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWAPPROVERSLISTREQUEST.fields_by_name['filter']._options = None
  _WORKFLOWAPPROVERSLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVERSLISTREQUEST._options = None
  _WORKFLOWAPPROVERSLISTREQUEST._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _WORKFLOWAPPROVERSLISTRESPONSE.fields_by_name['workflow_approvers']._options = None
  _WORKFLOWAPPROVERSLISTRESPONSE.fields_by_name['workflow_approvers']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _WORKFLOWAPPROVERSLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWAPPROVERSLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWAPPROVERSLISTRESPONSE._options = None
  _WORKFLOWAPPROVERSLISTRESPONSE._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _WORKFLOWAPPROVER.fields_by_name['id']._options = None
  _WORKFLOWAPPROVER.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVER.fields_by_name['workflow_id']._options = None
  _WORKFLOWAPPROVER.fields_by_name['workflow_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _WORKFLOWAPPROVER.fields_by_name['account_id']._options = None
  _WORKFLOWAPPROVER.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVER.fields_by_name['role_id']._options = None
  _WORKFLOWAPPROVER.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWAPPROVER._options = None
  _WORKFLOWAPPROVER._serialized_options = b'\030\001\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _WORKFLOWAPPROVERS._options = None
  _WORKFLOWAPPROVERS._serialized_options = b'\312\371\263\007\025\302\371\263\007\020WorkflowApprover\312\371\263\007\010\322\371\263\007\003nt-\312\371\263\007\005\350\371\263\007\001'
  _WORKFLOWAPPROVERS.methods_by_name['Create']._options = None
  _WORKFLOWAPPROVERS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\033\252\363\263\007\026/v1/workflow-approvers'
  _WORKFLOWAPPROVERS.methods_by_name['Get']._options = None
  _WORKFLOWAPPROVERS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\037\252\363\263\007\032/v1/workflow-approver/{id}'
  _WORKFLOWAPPROVERS.methods_by_name['Delete']._options = None
  _WORKFLOWAPPROVERS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\033\252\363\263\007\026/v1/workflow-approvers'
  _WORKFLOWAPPROVERS.methods_by_name['List']._options = None
  _WORKFLOWAPPROVERS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/workflow-approvers'
  _WORKFLOWAPPROVERSCREATEREQUEST._serialized_start=60
  _WORKFLOWAPPROVERSCREATEREQUEST._serialized_end=206
  _WORKFLOWAPPROVERSCREATERESPONSE._serialized_start=209
  _WORKFLOWAPPROVERSCREATERESPONSE._serialized_end=446
  _WORKFLOWAPPROVERGETREQUEST._serialized_start=448
  _WORKFLOWAPPROVERGETREQUEST._serialized_end=538
  _WORKFLOWAPPROVERGETRESPONSE._serialized_start=541
  _WORKFLOWAPPROVERGETRESPONSE._serialized_end=783
  _WORKFLOWAPPROVERSDELETEREQUEST._serialized_start=785
  _WORKFLOWAPPROVERSDELETEREQUEST._serialized_end=894
  _WORKFLOWAPPROVERSDELETERESPONSE._serialized_start=897
  _WORKFLOWAPPROVERSDELETERESPONSE._serialized_end=1073
  _WORKFLOWAPPROVERSLISTREQUEST._serialized_start=1075
  _WORKFLOWAPPROVERSLISTREQUEST._serialized_end=1190
  _WORKFLOWAPPROVERSLISTRESPONSE._serialized_start=1193
  _WORKFLOWAPPROVERSLISTRESPONSE._serialized_end=1433
  _WORKFLOWAPPROVER._serialized_start=1436
  _WORKFLOWAPPROVER._serialized_end=1597
  _WORKFLOWAPPROVERS._serialized_start=1600
  _WORKFLOWAPPROVERS._serialized_end=2183
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: resources_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import drivers_pb2 as drivers__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17resources_history.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\rdrivers.proto\x1a\roptions.proto\x1a\nspec.proto\"\x89\x01\n\x1aResourceHistoryListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xfa\x01\n\x1bResourceHistoryListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x30\n\x07history\x18\x02 \x03(\x0b\x32\x13.v1.ResourceHistoryB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x89\x02\n\x0fResourceHistory\x12\x1f\n\x0b\x61\x63tivity_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08resource\x18\x03 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ndeleted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xd6\x01\n\x10ResourcesHistory\x12u\n\x04List\x12\x1e.v1.ResourceHistoryListRequest\x1a\x1f.v1.ResourceHistoryListResponse\",\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1a\xaa\xf3\xb3\x07\x15/v1/resources-history\x1aK\xca\xf9\xb3\x07\x14\xc2\xf9\xb3\x07\x0fResourceHistory\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x94\x01\n\x19\x63om.strongdm.api.plumbingB\x18ResourcesHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_RESOURCEHISTORYLISTREQUEST = DESCRIPTOR.message_types_by_name['ResourceHistoryListRequest']
_RESOURCEHISTORYLISTRESPONSE = DESCRIPTOR.message_types_by_name['ResourceHistoryListResponse']
_RESOURCEHISTORY = DESCRIPTOR.message_types_by_name['ResourceHistory']
ResourceHistoryListRequest = _reflection.GeneratedProtocolMessageType('ResourceHistoryListRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYLISTREQUEST,
  '__module__' : 'resources_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceHistoryListRequest)
  })
_sym_db.RegisterMessage(ResourceHistoryListRequest)

ResourceHistoryListResponse = _reflection.GeneratedProtocolMessageType('ResourceHistoryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYLISTRESPONSE,
  '__module__' : 'resources_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceHistoryListResponse)
  })
_sym_db.RegisterMessage(ResourceHistoryListResponse)

ResourceHistory = _reflection.GeneratedProtocolMessageType('ResourceHistory', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORY,
  '__module__' : 'resources_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceHistory)
  })
_sym_db.RegisterMessage(ResourceHistory)

_RESOURCESHISTORY = DESCRIPTOR.services_by_name['ResourcesHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\030ResourcesHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _RESOURCEHISTORYLISTREQUEST.fields_by_name['filter']._options = None
  _RESOURCEHISTORYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHISTORYLISTREQUEST._options = None
  _RESOURCEHISTORYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _RESOURCEHISTORYLISTRESPONSE.fields_by_name['history']._options = None
  _RESOURCEHISTORYLISTRESPONSE.fields_by_name['history']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _RESOURCEHISTORYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEHISTORYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEHISTORYLISTRESPONSE._options = None
  _RESOURCEHISTORYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _RESOURCEHISTORY.fields_by_name['activity_id']._options = None
  _RESOURCEHISTORY.fields_by_name['activity_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHISTORY.fields_by_name['timestamp']._options = None
  _RESOURCEHISTORY.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHISTORY.fields_by_name['resource']._options = None
  _RESOURCEHISTORY.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHISTORY.fields_by_name['deleted_at']._options = None
  _RESOURCEHISTORY.fields_by_name['deleted_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHISTORY._options = None
  _RESOURCEHISTORY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _RESOURCESHISTORY._options = None
  _RESOURCESHISTORY._serialized_options = b'\312\371\263\007\024\302\371\263\007\017ResourceHistory\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _RESOURCESHISTORY.methods_by_name['List']._options = None
  _RESOURCESHISTORY.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\032\252\363\263\007\025/v1/resources-history'
  _RESOURCEHISTORYLISTREQUEST._serialized_start=107
  _RESOURCEHISTORYLISTREQUEST._serialized_end=244
  _RESOURCEHISTORYLISTRESPONSE._serialized_start=247
  _RESOURCEHISTORYLISTRESPONSE._serialized_end=497
  _RESOURCEHISTORY._serialized_start=500
  _RESOURCEHISTORY._serialized_end=765
  _RESOURCESHISTORY._serialized_start=768
  _RESOURCESHISTORY._serialized_end=982
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import secret_engines_pb2 as secret__engines__pb2
from . import secret_stores_pb2 as secret__stores__pb2


class SecretEnginesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/v1.SecretEngines/List',
                request_serializer=secret__engines__pb2.SecretEngineListRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.SecretEngineListResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/v1.SecretEngines/Get',
                request_serializer=secret__engines__pb2.SecretEngineGetRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.SecretEngineGetResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/v1.SecretEngines/Create',
                request_serializer=secret__engines__pb2.SecretEngineCreateRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.SecretEngineCreateResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/v1.SecretEngines/Update',
                request_serializer=secret__engines__pb2.SecretEngineUpdateRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.SecretEngineUpdateResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/v1.SecretEngines/Delete',
                request_serializer=secret__engines__pb2.SecretEngineDeleteRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.SecretEngineDeleteResponse.FromString,
                )
        self.ListSecretStores = channel.unary_unary(
                '/v1.SecretEngines/ListSecretStores',
                request_serializer=secret__stores__pb2.SecretStoreListRequest.SerializeToString,
                response_deserializer=secret__stores__pb2.SecretStoreListResponse.FromString,
                )
        self.GenerateKeys = channel.unary_unary(
                '/v1.SecretEngines/GenerateKeys',
                request_serializer=secret__engines__pb2.GenerateKeysRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.GenerateKeysResponse.FromString,
                )
        self.Healthcheck = channel.unary_unary(
                '/v1.SecretEngines/Healthcheck',
                request_serializer=secret__engines__pb2.HealthcheckRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.HealthcheckResponse.FromString,
                )
        self.Rotate = channel.unary_unary(
                '/v1.SecretEngines/Rotate',
                request_serializer=secret__engines__pb2.SecretEngineRotateRequest.SerializeToString,
                response_deserializer=secret__engines__pb2.SecretEngineRotateResponse.FromString,
                )


class SecretEnginesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def List(self, request, context):
        """List returns a list of Secret Engines
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get returns a secret engine details
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Create creates a secret engine
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update updates a secret engine
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete deletes a secret engine
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSecretStores(self, request, context):
        """ListSecretStores returns a list of Secret Stores that can be used as a backing store
        for Secret Engine
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateKeys(self, request, context):
        """GenerateKeys generates a private key, stores it in a secret store and stores a public key in a secret engine
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Healthcheck(self, request, context):
        """Healthcheck triggers a healthcheck for all nodes serving a secret engine
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rotate(self, request, context):
        """Rotate rotates secret engine's credentials
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretEnginesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=secret__engines__pb2.SecretEngineListRequest.FromString,
                    response_serializer=secret__engines__pb2.SecretEngineListResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=secret__engines__pb2.SecretEngineGetRequest.FromString,
                    response_serializer=secret__engines__pb2.SecretEngineGetResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=secret__engines__pb2.SecretEngineCreateRequest.FromString,
                    response_serializer=secret__engines__pb2.SecretEngineCreateResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=secret__engines__pb2.SecretEngineUpdateRequest.FromString,
                    response_serializer=secret__engines__pb2.SecretEngineUpdateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=secret__engines__pb2.SecretEngineDeleteRequest.FromString,
                    response_serializer=secret__engines__pb2.SecretEngineDeleteResponse.SerializeToString,
            ),
            'ListSecretStores': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSecretStores,
                    request_deserializer=secret__stores__pb2.SecretStoreListRequest.FromString,
                    response_serializer=secret__stores__pb2.SecretStoreListResponse.SerializeToString,
            ),
            'GenerateKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateKeys,
                    request_deserializer=secret__engines__pb2.GenerateKeysRequest.FromString,
                    response_serializer=secret__engines__pb2.GenerateKeysResponse.SerializeToString,
            ),
            'Healthcheck': grpc.unary_unary_rpc_method_handler(
                    servicer.Healthcheck,
                    request_deserializer=secret__engines__pb2.HealthcheckRequest.FromString,
                    response_serializer=secret__engines__pb2.HealthcheckResponse.SerializeToString,
            ),
            'Rotate': grpc.unary_unary_rpc_method_handler(
                    servicer.Rotate,
                    request_deserializer=secret__engines__pb2.SecretEngineRotateRequest.FromString,
                    response_serializer=secret__engines__pb2.SecretEngineRotateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.SecretEngines', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretEngines(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/List',
            secret__engines__pb2.SecretEngineListRequest.SerializeToString,
            secret__engines__pb2.SecretEngineListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/Get',
            secret__engines__pb2.SecretEngineGetRequest.SerializeToString,
            secret__engines__pb2.SecretEngineGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/Create',
            secret__engines__pb2.SecretEngineCreateRequest.SerializeToString,
            secret__engines__pb2.SecretEngineCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/Update',
            secret__engines__pb2.SecretEngineUpdateRequest.SerializeToString,
            secret__engines__pb2.SecretEngineUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/Delete',
            secret__engines__pb2.SecretEngineDeleteRequest.SerializeToString,
            secret__engines__pb2.SecretEngineDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSecretStores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/ListSecretStores',
            secret__stores__pb2.SecretStoreListRequest.SerializeToString,
            secret__stores__pb2.SecretStoreListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/GenerateKeys',
            secret__engines__pb2.GenerateKeysRequest.SerializeToString,
            secret__engines__pb2.GenerateKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Healthcheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/Healthcheck',
            secret__engines__pb2.HealthcheckRequest.SerializeToString,
            secret__engines__pb2.HealthcheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Rotate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretEngines/Rotate',
            secret__engines__pb2.SecretEngineRotateRequest.SerializeToString,
            secret__engines__pb2.SecretEngineRotateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proxy_cluster_keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18proxy_cluster_keys.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"\x83\x01\n\x1cProxyClusterKeyCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12:\n\x11proxy_cluster_key\x18\x02 \x01(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x9b\x02\n\x1dProxyClusterKeyCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\x11proxy_cluster_key\x18\x02 \x01(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\nsecret_key\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xf0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"Y\n\x19ProxyClusterKeyGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf0\x01\n\x1aProxyClusterKeyGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\x11proxy_cluster_key\x18\x02 \x01(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"_\n\x1cProxyClusterKeyDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xba\x01\n\x1dProxyClusterKeyDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"_\n\x1aProxyClusterKeyListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xdb\x01\n\x1bProxyClusterKeyListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12;\n\x12proxy_cluster_keys\x18\x02 \x03(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x90\x03\n\x0fProxyClusterKey\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12.\n\x10proxy_cluster_id\x18\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xe0\xf3\xb3\x07\x01\x12]\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\x12_\n\x0clast_used_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider:u\xfa\xf8\xb3\x07\x66\xc2\xf3\xb3\x07\x61\xa2\xf3\xb3\x07*tf_examples/proxy_cluster_key_resource.txt\xaa\xf3\xb3\x07-tf_examples/proxy_cluster_key_data_source.txt\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xbc\x04\n\x10ProxyClusterKeys\x12}\n\x06\x43reate\x12 .v1.ProxyClusterKeyCreateRequest\x1a!.v1.ProxyClusterKeyCreateResponse\".\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/proxy-cluster-keys\x12x\n\x03Get\x12\x1d.v1.ProxyClusterKeyGetRequest\x1a\x1e.v1.ProxyClusterKeyGetResponse\"2\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/proxy-cluster-keys/{id}\x12\x84\x01\n\x06\x44\x65lete\x12 .v1.ProxyClusterKeyDeleteRequest\x1a!.v1.ProxyClusterKeyDeleteResponse\"5\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/proxy-cluster-keys/{id}\x12v\n\x04List\x12\x1e.v1.ProxyClusterKeyListRequest\x1a\x1f.v1.ProxyClusterKeyListResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/proxy-cluster-keys\x1a\x30\xca\xf9\xb3\x07\x14\xc2\xf9\xb3\x07\x0fProxyClusterKey\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03gk-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42l\n\x19\x63om.strongdm.api.plumbingB\x18ProxyClusterKeysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_PROXYCLUSTERKEYCREATEREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyCreateRequest']
_PROXYCLUSTERKEYCREATERESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyCreateResponse']
_PROXYCLUSTERKEYGETREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyGetRequest']
_PROXYCLUSTERKEYGETRESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyGetResponse']
_PROXYCLUSTERKEYDELETEREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyDeleteRequest']
_PROXYCLUSTERKEYDELETERESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyDeleteResponse']
_PROXYCLUSTERKEYLISTREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyListRequest']
_PROXYCLUSTERKEYLISTRESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyListResponse']
_PROXYCLUSTERKEY = DESCRIPTOR.message_types_by_name['ProxyClusterKey']
ProxyClusterKeyCreateRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYCREATEREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyCreateRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyCreateRequest)

ProxyClusterKeyCreateResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYCREATERESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyCreateResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyCreateResponse)

ProxyClusterKeyGetRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYGETREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyGetRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyGetRequest)

ProxyClusterKeyGetResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYGETRESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyGetResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyGetResponse)

ProxyClusterKeyDeleteRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYDELETEREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyDeleteRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyDeleteRequest)

ProxyClusterKeyDeleteResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYDELETERESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyDeleteResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyDeleteResponse)

ProxyClusterKeyListRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyListRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYLISTREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyListRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyListRequest)

ProxyClusterKeyListResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYLISTRESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyListResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyListResponse)

ProxyClusterKey = _reflection.GeneratedProtocolMessageType('ProxyClusterKey', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEY,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKey)
  })
_sym_db.RegisterMessage(ProxyClusterKey)

_PROXYCLUSTERKEYS = DESCRIPTOR.services_by_name['ProxyClusterKeys']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\030ProxyClusterKeysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _PROXYCLUSTERKEYCREATEREQUEST.fields_by_name['proxy_cluster_key']._options = None
  _PROXYCLUSTERKEYCREATEREQUEST.fields_by_name['proxy_cluster_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['meta']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['proxy_cluster_key']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['proxy_cluster_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['secret_key']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['secret_key']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\360\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEYCREATERESPONSE._options = None
  _PROXYCLUSTERKEYCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYGETREQUEST.fields_by_name['id']._options = None
  _PROXYCLUSTERKEYGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['meta']._options = None
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['proxy_cluster_key']._options = None
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['proxy_cluster_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEYGETRESPONSE._options = None
  _PROXYCLUSTERKEYGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYDELETEREQUEST.fields_by_name['id']._options = None
  _PROXYCLUSTERKEYDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['meta']._options = None
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEYDELETERESPONSE._options = None
  _PROXYCLUSTERKEYDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYLISTREQUEST.fields_by_name['filter']._options = None
  _PROXYCLUSTERKEYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['proxy_cluster_keys']._options = None
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['proxy_cluster_keys']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEY.fields_by_name['id']._options = None
  _PROXYCLUSTERKEY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEY.fields_by_name['proxy_cluster_id']._options = None
  _PROXYCLUSTERKEY.fields_by_name['proxy_cluster_id']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\300\363\263\007\001\340\363\263\007\001'
  _PROXYCLUSTERKEY.fields_by_name['created_at']._options = None
  _PROXYCLUSTERKEY.fields_by_name['created_at']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _PROXYCLUSTERKEY.fields_by_name['last_used_at']._options = None
  _PROXYCLUSTERKEY.fields_by_name['last_used_at']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _PROXYCLUSTERKEY._options = None
  _PROXYCLUSTERKEY._serialized_options = b'\372\370\263\007f\302\363\263\007a\242\363\263\007*tf_examples/proxy_cluster_key_resource.txt\252\363\263\007-tf_examples/proxy_cluster_key_data_source.txt\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYS._options = None
  _PROXYCLUSTERKEYS._serialized_options = b'\312\371\263\007\024\302\371\263\007\017ProxyClusterKey\312\371\263\007\010\322\371\263\007\003gk-\312\371\263\007\005\350\371\263\007\001'
  _PROXYCLUSTERKEYS.methods_by_name['Create']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\033\252\363\263\007\026/v1/proxy-cluster-keys'
  _PROXYCLUSTERKEYS.methods_by_name['Get']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007 \252\363\263\007\033/v1/proxy-cluster-keys/{id}'
  _PROXYCLUSTERKEYS.methods_by_name['Delete']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007 \252\363\263\007\033/v1/proxy-cluster-keys/{id}'
  _PROXYCLUSTERKEYS.methods_by_name['List']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/proxy-cluster-keys'
  _PROXYCLUSTERKEYCREATEREQUEST._serialized_start=93
  _PROXYCLUSTERKEYCREATEREQUEST._serialized_end=224
  _PROXYCLUSTERKEYCREATERESPONSE._serialized_start=227
  _PROXYCLUSTERKEYCREATERESPONSE._serialized_end=510
  _PROXYCLUSTERKEYGETREQUEST._serialized_start=512
  _PROXYCLUSTERKEYGETREQUEST._serialized_end=601
  _PROXYCLUSTERKEYGETRESPONSE._serialized_start=604
  _PROXYCLUSTERKEYGETRESPONSE._serialized_end=844
  _PROXYCLUSTERKEYDELETEREQUEST._serialized_start=846
  _PROXYCLUSTERKEYDELETEREQUEST._serialized_end=941
  _PROXYCLUSTERKEYDELETERESPONSE._serialized_start=944
  _PROXYCLUSTERKEYDELETERESPONSE._serialized_end=1130
  _PROXYCLUSTERKEYLISTREQUEST._serialized_start=1132
  _PROXYCLUSTERKEYLISTREQUEST._serialized_end=1227
  _PROXYCLUSTERKEYLISTRESPONSE._serialized_start=1230
  _PROXYCLUSTERKEYLISTRESPONSE._serialized_end=1449
  _PROXYCLUSTERKEY._serialized_start=1452
  _PROXYCLUSTERKEY._serialized_end=1852
  _PROXYCLUSTERKEYS._serialized_start=1855
  _PROXYCLUSTERKEYS._serialized_end=2427
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import account_grants_history_pb2 as account__grants__history__pb2


class AccountGrantsHistoryStub(object):
    """AccountGrantsHistory records all changes to the state of an AccountGrant.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/v1.AccountGrantsHistory/List',
                request_serializer=account__grants__history__pb2.AccountGrantHistoryListRequest.SerializeToString,
                response_deserializer=account__grants__history__pb2.AccountGrantHistoryListResponse.FromString,
                )


class AccountGrantsHistoryServicer(object):
    """AccountGrantsHistory records all changes to the state of an AccountGrant.
    """

    def List(self, request, context):
        """List gets a list of AccountGrantHistory records matching a given set of criteria.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountGrantsHistoryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=account__grants__history__pb2.AccountGrantHistoryListRequest.FromString,
                    response_serializer=account__grants__history__pb2.AccountGrantHistoryListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.AccountGrantsHistory', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccountGrantsHistory(object):
    """AccountGrantsHistory records all changes to the state of an AccountGrant.
    """

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.AccountGrantsHistory/List',
            account__grants__history__pb2.AccountGrantHistoryListRequest.SerializeToString,
            account__grants__history__pb2.AccountGrantHistoryListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
